********************************************************************************
************************* REGRESSION ANALYSIS SPAIN ****************************
********************************************************************************

* Data 
use "${data_created}/EPA_indiv_panel.dta", clear //read in Spanish dataset (2019-2020)


* Locals & globals
global controls i.sum_edu i.Qt i.migrate i.age_grp i.simp_educ i.married

global worktype "Dt##i.work_type" 

local out_reg_table = "${out}/Spain_DiD.xlsx"

local samp_yr = 2019       // sample year to start regressions



************************************
* Descriptive statistics, Table C8 *
************************************

* Tabulate data for appendix table C8
gen single_mother=0
replace single_mother=1 if sex==2 & (child_grp==1 | child_grp==2) & mar_cohab==0

gen obs=_N

local vars obs broad_emp sex married single_mother child_grp migrate college
foreach x of local vars {
	tab `x' [aw=wtfinl] 
}

sum raw_hours_lwk [aw=wtfinl]


******************************************
* Base specifications - Broad Employment *
******************************************

// SPEC 1: aggregates broad employment
preserve

keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Overall change, without controls (except quarter and education dummies)
qui reg broad_emp  Dt                                     i.sum_edu i.Qt  [pw=wtfinl],  robust 
est store bench_nocontrols  
matrix table_bench_nocontrols = r(table) //store reg results

* Overall change, with benchmark controls (except gender specific time trend)
qui reg broad_emp Dt                                     $controls [pw=wtfinl],  robust 
est store bench_controls  
matrix table_bench_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 7a") replace 
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Broad employment (no cont)"
putexcel B2=table_bench_nocontrols[1,1] 
putexcel B3=table_bench_nocontrols[2,1] 
putexcel B4=table_bench_nocontrols[4,1] 

putexcel C1 =  "Broad employment (with cont)"
putexcel C2=table_bench_controls[1,1] 
putexcel C3=table_bench_controls[2,1] 
putexcel C4=table_bench_controls[4,1] 

restore


// SPEC 1A: Broad Employment, includes summer education dummies, interacted with detailed child groups, only gender specific trends
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
qui reg broad_emp Dt##ib1.sex c.time_var#ib1.sex                                      $controls [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results


qui reg broad_emp Dt##ib1.sex  c.time_var#ib1.sex  $worktype                    $controls [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
qui reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex                       $controls [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results


qui reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex  $worktype      $controls [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 7b") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,22]   
putexcel C3=table_kid[2,22] 
putexcel C4=table_kid[4,22] 

putexcel D1 =  "Small Kids (bench)"
putexcel D2=table_kid[1,23] 
putexcel D3=table_kid[2,23] 
putexcel D4=table_kid[4,23] 

putexcel E1 =  "School Kids (bench)"
putexcel E2=table_kid[1,24] 
putexcel E3=table_kid[2,24] 
putexcel E4=table_kid[4,24] 

//...and with occ controls

* Regression Results
putexcel F1 =  "Population (work type)"
putexcel F2=table_bench_occ[1,8] 
putexcel F3=table_bench_occ[2,8] 
putexcel F4=table_bench_occ[4,8] 

putexcel G1 =  "No Kids (work type)"
putexcel G2=table_kid_occ[1,22]   
putexcel G3=table_kid_occ[2,22] 
putexcel G4=table_kid_occ[4,22] 

putexcel H1 =  "Small Kids (work type)"
putexcel H2=table_kid_occ[1,23] 
putexcel H3=table_kid_occ[2,23] 
putexcel H4=table_kid_occ[4,23] 

putexcel I1 =  "School Kids (work type)"
putexcel I2=table_kid_occ[1,24] 
putexcel I3=table_kid_occ[2,24] 
putexcel I4=table_kid_occ[4,24] 




*****************************************
* Base specifications - Hours Last Week *
*****************************************

// SPEC 2: hrs last week aggregates
preserve

keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Overall change, without controls (except quarter and education dummies)
qui reg hours_lwk Dt                                     i.sum_edu i.Qt  [pw=wtfinl],  robust 
est store bench_nocontrols  
matrix table_bench_nocontrols = r(table) //store reg results

* Overall change, with benchmark controls
qui reg hours_lwk Dt                                     $controls [pw=wtfinl],  robust 
est store bench_controls  
matrix table_bench_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 8a") modify 
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Overall Hrs_lwk (no cont)"
putexcel B2=table_bench_nocontrols[1,1] 
putexcel B3=table_bench_nocontrols[2,1] 
putexcel B4=table_bench_nocontrols[4,1] 

putexcel C1 =  "Overall Hrs_lwk (with cont)"
putexcel C2=table_bench_controls[1,1] 
putexcel C3=table_bench_controls[2,1] 
putexcel C4=table_bench_controls[4,1] 

restore


// SPEC 2A: Hours last week, includes summer education dummies, interacted with detailed child groups, only gender specific trends
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
qui reg hours_lwk Dt##ib1.sex c.time_var#ib1.sex                                      $controls [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

qui reg hours_lwk Dt##ib1.sex  c.time_var#ib1.sex  $worktype                    $controls [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
qui reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex                       $controls [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

qui reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex  $worktype      $controls [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...

putexcel set `out_reg_table' , sheet("Table 8b") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,22]   
putexcel C3=table_kid[2,22] 
putexcel C4=table_kid[4,22] 

putexcel D1 =  "Small Kids (bench)"
putexcel D2=table_kid[1,23] 
putexcel D3=table_kid[2,23] 
putexcel D4=table_kid[4,23] 

putexcel E1 =  "School Kids (bench)"
putexcel E2=table_kid[1,24] 
putexcel E3=table_kid[2,24] 
putexcel E4=table_kid[4,24] 

//...and with occ controls

* Regression Results
putexcel F1 =  "Population (work type)"
putexcel F2=table_bench_occ[1,8] 
putexcel F3=table_bench_occ[2,8] 
putexcel F4=table_bench_occ[4,8] 

putexcel G1 =  "No Kids (work type)"
putexcel G2=table_kid_occ[1,22]   
putexcel G3=table_kid_occ[2,22] 
putexcel G4=table_kid_occ[4,22] 

putexcel H1 =  "Small Kids (work type)"
putexcel H2=table_kid_occ[1,23] 
putexcel H3=table_kid_occ[2,23] 
putexcel H4=table_kid_occ[4,23] 

putexcel I1 =  "School Kids (work type)"
putexcel I2=table_kid_occ[1,24] 
putexcel I3=table_kid_occ[2,24] 
putexcel I4=table_kid_occ[4,24] 




*************************************
* Specifications - Education Levels *
*************************************

// SPEC 3A: Employment Education Regressions

* The following regressions produce tables 11 and A3

preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
 reg broad_emp Dt##ib1.sex#ib0.college c.time_var#ib1.sex                                        $controls [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.college  c.time_var#ib1.sex  $worktype                     $controls [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex                        $controls [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex  $worktype        $controls [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 11") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 

putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 

putexcel F1 =  "Small Kids Low Skill  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids High Skill  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 

putexcel H1 =  "School Kids Low Skill  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids High Skill  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop Low Skill (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop High Skill (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 

putexcel L1 =  "No Kids Low Skill  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids High Skill  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 

putexcel N1 =  "Small Kids Low Skill  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids High Skill  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 

putexcel P1 =  "School Kids Low Skill  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids High Skill  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 



// SPEC 3B: Hours Education Regressions

* The following regressions produce tables 12 and A4

preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
 reg hours_lwk Dt##ib1.sex#ib0.college c.time_var#ib1.sex                                        $controls [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.college  c.time_var#ib1.sex  $worktype                     $controls [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex                        $controls [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex  $worktype        $controls [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 

* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 12") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids Low Skill  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids High Skill  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids Low Skill  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids High Skill  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 

//...and with occ controls

putexcel J1 =  "Pop Low Skill (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop High Skill (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids Low Skill  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids High Skill  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids Low Skill  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids High Skill  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids Low Skill  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids High Skill  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 



********************************************************************************
* Regressions: Broad Race (white v non-white) *
***********************************************

global controls
global controls i.sum_edu i.Qt i.age_grp i.simp_educ i.married

// SPEC 4A: Employment gender gap and broad race (white v non-white)

* The following regressions produce tables 13 and A5 

preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
  reg broad_emp Dt##ib1.sex#i.migrate c.time_var#ib1.sex                                      $controls [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

  reg broad_emp Dt##ib1.sex#i.migrate  c.time_var#ib1.sex  $worktype                    $controls [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg broad_emp Dt##ib1.sex#ib0.child_grp#i.migrate  c.time_var#ib1.sex                       $controls [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.child_grp#i.migrate  c.time_var#ib1.sex  $worktype      $controls [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 13") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids White  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids Non-white  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids White  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids Non-white  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop White (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop Non-white (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids White  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids Non-white  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids White  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids Non-white  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids White  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids Non-white  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 


// SPEC 4B: Hours gender gap and broad race (white v non-white)

* The following regressions produce tables 14 and A6

preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
  reg hours_lwk Dt##ib1.sex#i.migrate c.time_var#ib1.sex                                      $controls [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

  reg hours_lwk Dt##ib1.sex#i.migrate  c.time_var#ib1.sex  $worktype                    $controls [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#i.migrate  c.time_var#ib1.sex                       $controls [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#i.migrate  c.time_var#ib1.sex  $worktype      $controls [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results


restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 14") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids White  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids Non-white  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids White  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids Non-white  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop White (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop Non-white (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids White  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids Non-white  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids White  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids Non-white  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids White  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids Non-white  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 


**********************************
* Regressions: Single Motherhood *
**********************************

global controls
global controls i.sum_edu i.Qt i.migrate i.age_grp i.simp_educ 

* Compare mothers who are working and not working by child group 


* Single by marital/cohabitation status
// SPEC 4: Hours Last Week & Broad Employment
preserve

* Mothers Sample
keep if sex==2 & (child_grp==1 | child_grp==2) // mothers of children < 18 only
//replace child_grp = 1 if child_grp==2

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Regression Set
* Hours
reg hours_lwk Dt##ib1.mar_cohab#ib0.child_grp    $controls [pw=wtfinl] , robust 							   
matrix motherhood = r(table) //store reg results

reg hours_lwk Dt##ib1.mar_cohab#ib0.child_grp Dt#i.work_type  $controls [pw=wtfinl] , robust 							   
matrix motherhood_occ = r(table) //store reg results

* Employment
reg broad_emp Dt##ib1.mar_cohab#ib0.child_grp    $controls [pw=wtfinl] , robust 							   
matrix motherhood_emp = r(table) //store reg results

reg broad_emp Dt##ib1.mar_cohab#ib0.child_grp Dt#i.work_type  $controls [pw=wtfinl] , robust 							   
matrix motherhood_emp_occ = r(table) //store reg results

restore


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 15") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

putexcel B1 =  "Hours Single Mom - Small Kids (bench)"
putexcel B2=motherhood[1,13]
putexcel B3=motherhood[2,13]
putexcel B4=motherhood[4,13]

putexcel C1 =  "Hours Single Mom - School Kids (bench)"
putexcel C2=motherhood[1,14]
putexcel C3=motherhood[2,14]
putexcel C4=motherhood[4,14]

putexcel D1 =  "Hours Single Mom - Small Kids (work type)"
putexcel D2=motherhood_occ[1,13]
putexcel D3=motherhood_occ[2,13]
putexcel D4=motherhood_occ[4,13]

putexcel E1 =  "Hours Single Mom - School Kids (work type)"
putexcel E2=motherhood_occ[1,14]
putexcel E3=motherhood_occ[2,14]
putexcel E4=motherhood_occ[4,14]


//employment
putexcel F1 =  "Employment Single Mom - Small Kids (bench)"
putexcel F2=motherhood_emp[1,13]
putexcel F3=motherhood_emp[2,13]
putexcel F4=motherhood_emp[4,13]

putexcel G1 =  "Employment Single Mom - School Kids (bench)"
putexcel G2=motherhood_emp[1,14]
putexcel G3=motherhood_emp[2,14]
putexcel G4=motherhood_emp[4,14]

putexcel H1 =  "Employment Single Mom - Small Kids (work type)"
putexcel H2=motherhood_emp_occ[1,13]
putexcel H3=motherhood_emp_occ[2,13]
putexcel H4=motherhood_emp_occ[4,13]

putexcel I1 =  "Employment Single Mom - School Kids (work type)"
putexcel I2=motherhood_emp_occ[1,14]
putexcel I3=motherhood_emp_occ[2,14]
putexcel I4=motherhood_emp_occ[4,14]

exit
