
* Preliminaries
cls
clear all
set maxvar 20000
set matsize 2000
set emptycells drop

* Directories *
global raw_data ".../Raw Data" 
global out_dir ".../Output/USA/DiD" 

* Log File
log using "${out_dir}/USA_DiD.log", replace

* Date *
use "${raw_data}/cps_00008.dta" if year >=2000 & year<=2020 , clear //read in CPS microdata from IPUMS

* Output Location for DiD Regression Results
local out_reg_table = "${out_dir}/USA_DiD.xlsx"
 

******************************************************************************** 
* Sample and Settings*
**********************


* Population Sample
keep if age>=25 & age<=55
drop if occ2010>=9800 & occ2010<=9830 //drop military
drop if ind>=9670 & ind<=9870  //drop military
keep if year>=2019
//drop if year == 2020 & month>=10 // only full quarters, comparable to other countries, drop october data since dont have in other countries


* Time Index 
gen time_var = ym(year,month)  //monthly time
gen sdate = string(time_var, "%tmmy") 
labmask time_var, val(sdate) // label time periods with month-year


* Auxiliary Settings
egen start_time = min(time_var)
local date_norm = ym(2020,2) -start_time +1  //normalization for plotting, Feb 2020 = 1
//drop start_time

local small_cutoff = 5       // transition baby to middle school age
local big_cutoff   = 14      // transition school age to high school

local samp_yr = 2019         // sample year to start regressions
 
********************************************************************************
* No More Settings Below Here * Automated Given Above *
******************************************************************************** 
* Create Variables *
********************


* Pandemic Treatment and Control
gen Dt = . 
replace Dt = 1 if year==2020 & month>=4 & month<=9   // post-pandemic = 1, 2020Q2 + 2020Q3
replace Dt = 0 if year==2020 & month>=1 & month<=3   // pre-pandemic = 0,  <= 2020Q1
replace Dt = 0 if year==2019

* Detailed Child Groups 
gen det_child_grp = .
replace det_child_grp = 0 if  nchild==0 // no children
replace det_child_grp = 1 if yngch<5 //pre-K
replace det_child_grp = 2 if yngch>=5 & yngch<14 // middle kids
replace det_child_grp = 3 if yngch>=14 & yngch<18 //HS
replace det_child_grp = 4 if yngch>=18 & yngch<22 // college
replace det_child_grp = 5 if yngch>=23 & yngch<99 // adult

*  Child Group 
gen child_grp = .
replace child_grp = 0 if  nchild==0 // no children
replace child_grp = 1 if yngch< `small_cutoff' // < 5 yo, small kids
replace child_grp = 2 if yngch>=`small_cutoff' & yngch<18 // 5-17 school age
replace child_grp = 0 if yngch>=18 & yngch<99 // youngest child >= 18 yo, same as no children 

* Simple Child Group 
gen simple_child_grp = .
replace simple_child_grp = 0 if yngch< 5 | yngch>=18 // no school age
replace simple_child_grp = 1 if yngch>=5 & yngch<18  //  school age, 5-17


* Broad Employment 
* (Employment-per-capita; combines unemployed and NILF, as in our model. Excludes armed services.)
gen broad_emp = .
replace broad_emp = 0 if (empstat>=21 & empstat<=22) | (empstat>=32 & empstat<=36) 
replace broad_emp = 1 if  empstat>=10 & empstat<=12


* Broad Hours Index
* (Broad Hours Index assigned 0 to those unemployed or NILF. For measurement, use hours worked last week rather than usual hours worked, given unusual short term nature of recession)

* usual hours 
* can replace last week hours from below; challenge then is to deal with seasonality in last week hours
gen raw_hours_usual = . //usual or last week (see below)
replace raw_hours_usual = uhrsworkt if uhrsworkt~=997  & uhrsworkt~=999  //usual hours worked metric, used as a robustness check\
replace raw_hours_usual = 0 if (uhrsworkt==997  | uhrsworkt==999)  & empstat==12 
replace raw_hours_usual = 0 if broad_emp==0 //unemployed and NILF get zero hours, for extensive margin
replace raw_hours_usual = . if raw_hours_usual>(24-8)*7 // drop those with impossibly high hours

* lask week hours
gen raw_hours_lwk = . // lwk hours show larger movements, but worse seasonality
replace raw_hours_lwk = ahrsworkt if ahrsworkt~=999  // hours worked last week, careful with missing values coded as 999
replace raw_hours_lwk = 0 if ahrsworkt==999 & empstat==12 // assign to those 0 hours, who are employed but did not work last week (empstat == 12) 
replace raw_hours_lwk = 0 if broad_emp==0 //unemployed and NILF get zero hours, for extensive margin
replace raw_hours_lwk = . if raw_hours_lwk>(24-8)*7 // drop those with impossibly high hours

* create hours index
//gen     hours = ln(1+raw_hours) // Broad Hours index = ln(1+raw_hours) [See: MacCurdy and Pencavel JPE 1986]
gen hours_usual = ln(raw_hours_usual + (1+raw_hours_usual^2)^(1/2)) // hyperbolic sine transformation to approximate log funciton
gen hours_lwk   = ln(raw_hours_lwk + (1+raw_hours_lwk^2)^(1/2)) // hyperbolic sine transformation to approximate log funciton

* Marital Status 
gen married = .
replace married = 1 if marst>=1 & marst<=2
replace married = 0 if marst>=3 & marst<=6


* Education
gen simp_educ = .
replace simp_educ = 0 if educ<71 // < less than hs diploma or equivalent
replace simp_educ = 1 if educ == 73 //  hs diploma or equivalent
replace simp_educ = 2 if educ >=81 & educ<=92 // some college or associatess
replace simp_educ = 3 if educ >=111 & educ<=125 // BA or more

gen college=.
replace college = 0 if educ>=2 & educ<=92    // less than BA
replace college = 1 if educ>=111 & educ<=125 // BA or more

* Simple race
gen simp_race = .
replace simp_race = 0 if race==100
replace simp_race = 1 if race>=200 & race<=900


* Age groups
gen age_grp = .
replace age_grp = 0 if age>=25 & age<30
replace age_grp = 1 if age>=30 & age<35
replace age_grp = 2 if age>=35 & age<40
replace age_grp = 3 if age>=40 & age<45
replace age_grp = 4 if age>=45 & age<50
replace age_grp = 5 if age>=50 & age<55 


* Occupations
gen simp_occ=. 
replace simp_occ = 1 if occ2010>=10 & occ2010<=430     // Management, Business, Science, and Arts = 10-430 
replace simp_occ = 2 if occ2010>=500 & occ2010<=730    // Business Operations Specialists = 500-730 
replace simp_occ = 3 if occ2010>=800 & occ2010<=950    // Financial Specialists = 800-950 
replace simp_occ = 4 if occ2010>=1000 & occ2010<=1240  // Computer and Mathematical = 1000-1240 
replace simp_occ = 5 if occ2010>=1300 & occ2010<=1540  // Architecture and Engineering = 1300-1540 
replace simp_occ = 6 if occ2010>=1550 & occ2010<=1560  // Technicians = 1550-1560 
replace simp_occ = 7 if occ2010>=1600 & occ2010<=1980  // Life, Physical, and Social Science = 1600-1980 
replace simp_occ = 8 if occ2010>=2000 & occ2010<=2060  // Community and Social Services = 2000-2060 
replace simp_occ = 9 if occ2010>=2100 & occ2010<=2150  // Legal = 2100-2150 
replace simp_occ = 10 if occ2010>=2200 & occ2010<=2550 // Education, Training, and Library = 2200-2550 
replace simp_occ = 11 if occ2010>=2600 & occ2010<=2920 // Arts, Design, Entertainment, Sports, and Media = 2600-2920 
replace simp_occ = 12 if occ2010>=3000 & occ2010<=3540 // Healthcare Practitioners and Technicians = 3000-3540 
replace simp_occ = 13 if occ2010>=3600 & occ2010<=3650 // Healthcare Support = 3600-3650 
replace simp_occ = 14 if occ2010>=3700 & occ2010<=3950 // Protective Service = 3700-3950 
replace simp_occ = 15 if occ2010>=4000 & occ2010<=4150 // Food Preparation and Serving = 4000-4150 
replace simp_occ = 16 if occ2010>=4200 & occ2010<=4250 // Building and Grounds Cleaning and Maintenance = 4200-4250 
replace simp_occ = 17 if occ2010>=4300 & occ2010<=4650 // Personal Care and Service = 4300-4650 
replace simp_occ = 18 if occ2010>=4700 & occ2010<=4965 // Sales and Related = 4700-4965 
replace simp_occ = 19 if occ2010>=5000 & occ2010<=5940 // Office and Administrative Support = 5000-5940 
replace simp_occ = 20 if occ2010>=6005 & occ2010<=6130 // Farming, Fishing, and Forestry = 6005-6130 
replace simp_occ = 21 if occ2010>=6200 & occ2010<=6765 // Construction = 6200-6765 
replace simp_occ = 22 if occ2010>=6800 & occ2010<=6940 // Extraction = 6800-6940 
replace simp_occ = 23 if occ2010>=7000 & occ2010<=7630 // Installation, Maintenance, and Repair = 7000-7630 
replace simp_occ = 24 if occ2010>=7700 & occ2010<=8965 // Production = 7700-8965 
replace simp_occ = 25 if occ2010>=9000 & occ2010<=9750 // Transportation and Material Moving = 9000-9750 
replace simp_occ = 26 if occ2010>=9800 & occ2010<=9830 // Military Specific = 9800-9830 
replace simp_occ = 99 if simp_occ==. & empstat>=22 & empstat<=36  // new workers and NILF holding place (necessary to avoid dropping in regressions)


gen simp_ind = .
replace simp_ind = 1 if ind>=170 & ind<=290 // agriculture and forestry
replace simp_ind = 2 if ind>=370 & ind<=490 // oil and gas extraction + mining
replace simp_ind = 3 if ind==770  			// construction
replace simp_ind = 4 if ind>=1070 & ind<=3990 //  manufacturing
replace simp_ind = 5 if ind>=4070 & ind<=4590 //  wholesale trade
replace simp_ind = 6 if ind>=4670 & ind<=5790 //  retail trade
replace simp_ind = 7 if ind>=6070 & ind<=6390 //  transportation and warehousing
replace simp_ind = 8 if ind>=570 & ind<=690  // utilities
replace simp_ind = 9 if ind>=6470 & ind<=6780 // information
replace simp_ind = 10 if ind>=6870 & ind<=6992 // finance and insurance
replace simp_ind = 11 if ind>=7071 & ind<=7190 // real estate, rentals, and leasing
replace simp_ind = 12 if ind>=7270 & ind<=7490 // professional, scientific, and technical services
replace simp_ind = 13 if ind==7570             // management of companies and enterprises
replace simp_ind = 14 if ind>=7580 & ind<=7790 // admin, support, waste management services
replace simp_ind = 15 if ind>=7860 & ind<=7890 // educational services
replace simp_ind = 16 if ind>=7970 & ind<=8470 // healthcare and social assistance
replace simp_ind = 17 if ind>=8561 & ind<=8590 // arts, entertainment, and recreation
replace simp_ind = 18 if ind>=8660 & ind<=8690 // accommodation and food services
replace simp_ind = 19 if ind>=8770 & ind<=9290 // other services, except public
replace simp_ind = 20 if ind>=9370 & ind<=9590 // public admin
replace simp_ind = 21 if ind>=9670 & ind<=9870 // military
replace simp_ind = 99 if simp_ind==. & empstat>=22 & empstat<=36 // new workers and NILF holding place (necessary to avoid dropping in regressions)

* Compound work type groups for regressions, simple industry x simple occupation 
replace simp_ind = 99 if simp_occ==99 & simp_ind~=.
replace simp_occ = 99 if simp_ind==99 & simp_occ~=.
egen work_type = group(simp_occ simp_ind), label 


* Quarterly dummies 
gen Qt = .
replace Qt = 1 if month>=1  & month<=3
replace Qt = 2 if month>=4  & month<=6
replace Qt = 3 if month>=7  & month<=9
replace Qt = 4 if month>=10 & month<=12

* Quarterly Time Series
gen time_qts = yq(year,Qt) // quarterly time
gen sdate_qts= string(time_qts, "%tq") 
labmask time_qts, val(sdate_qts) // label time periods with quarterly labels


// Summer Education Sector Indicator
gen sum_edu = 0
replace sum_edu = 1 if simp_ind==15 & month>=6 & month<=8


********************************************************************************
* Regressions: Hours Last Week *
********************************


// SPEC 1: hrs last week aggregates
preserve

keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Overall change, without controls (except quarter and education dummies)
qui reg hours_lwk Dt                                     i.sum_edu i.Qt  [pw=wtfinl],  robust 
est store bench_nocontrols  
matrix table_bench_nocontrols = r(table) //store reg results


* Overall change, with benchmark controls
qui reg hours_lwk Dt                                     i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store bench_controls  
matrix table_bench_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 8a") modify 
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Overall Hrs_lwk (no cont)"
putexcel B2=table_bench_nocontrols[1,1] 
putexcel B3=table_bench_nocontrols[2,1] 
putexcel B4=table_bench_nocontrols[4,1] 

putexcel C1 =  "Overall Hrs_lwk (with cont)"
putexcel C2=table_bench_controls[1,1] 
putexcel C3=table_bench_controls[2,1] 
putexcel C4=table_bench_controls[4,1] 



restore


// SPEC 1A: Hours last week, includes summer education dummies, interacted with detailed child groups, only gender specific trends
preserve


* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
qui reg hours_lwk Dt##ib1.sex c.time_var#ib1.sex                                      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

qui reg hours_lwk Dt##ib1.sex  c.time_var#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex                       i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results


restore 


#delimit ;
coefplot  (bench,label(Population)) (kid,  label(Kid Interaction))    , bylabel("Benchmark") 
|| (bench_occ,  label(Population)) (kid_occ, label(Kid Interaction)) ,bylabel("Ind and Occ Controls") yscale(range(-0.15(0.05)0))
name(hours_lwk_kids,replace) vertical drop(_cons) keep(1.Dt#2.sex*) yline(0) title("") graphregion(color(white)) ytitle("hours last week")
coeflabels(1.Dt#2.sex="Pop" 1.Dt#2.sex#0.child_grp="None" 1.Dt#2.sex#1.child_grp="< 5 " 1.Dt#2.sex#2.child_grp="5-17 "  ,wrap(20) interaction(" x ")) 
baselevel legend(r(1)) levels(95) ciopts(recast(rcap))  graphregion(color(white));
#delimit cr


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 8b") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,22]   
putexcel C3=table_kid[2,22] 
putexcel C4=table_kid[4,22] 

putexcel D1 =  "Small Kids (bench)"
putexcel D2=table_kid[1,23] 
putexcel D3=table_kid[2,23] 
putexcel D4=table_kid[4,23] 

putexcel E1 =  "School Kids (bench)"
putexcel E2=table_kid[1,24] 
putexcel E3=table_kid[2,24] 
putexcel E4=table_kid[4,24] 

//...and with occ controls

* Regression Results
putexcel F1 =  "Population (work type)"
putexcel F2=table_bench_occ[1,8] 
putexcel F3=table_bench_occ[2,8] 
putexcel F4=table_bench_occ[4,8] 

putexcel G1 =  "No Kids (work type)"
putexcel G2=table_kid_occ[1,22]   
putexcel G3=table_kid_occ[2,22] 
putexcel G4=table_kid_occ[4,22] 

putexcel H1 =  "Small Kids (work type)"
putexcel H2=table_kid_occ[1,23] 
putexcel H3=table_kid_occ[2,23] 
putexcel H4=table_kid_occ[4,23] 

putexcel I1 =  "School Kids (work type)"
putexcel I2=table_kid_occ[1,24] 
putexcel I3=table_kid_occ[2,24] 
putexcel I4=table_kid_occ[4,24] 




// SPEC 1B: Hours last week, includes summer education dummies, interacted with detailed child groups, gender x child_grp specific trends
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
qui reg hours_lwk Dt##ib1.sex c.time_var#ib1.sex                                                 i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store bench  


qui reg hours_lwk Dt##ib1.sex  c.time_var#ib1.sex  Dt##i.work_type                               i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust  
est store bench_occ


* By Child Group
qui reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex#ib0.child_grp                    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store kid

qui reg hours_lwk Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex#ib0.child_grp   Dt##i.work_type  i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store  kid_occ

restore 



#delimit ;
coefplot  (bench,label(Population)) (kid,  label(Kid Interaction))    , bylabel("Benchmark") 
|| (bench_occ,  label(Population)) (kid_occ, label(Kid Interaction)) ,bylabel("Ind and Occ Controls") /*yscale(range(-0.15(0.05)0))*/
name(hours_lwk_kids_kidtrends,replace) vertical drop(_cons) keep(1.Dt#2.sex*) yline(0) title("") graphregion(color(white)) ytitle("hours last week")
coeflabels(1.Dt#2.sex="Pop" 1.Dt#2.sex#0.child_grp="None" 1.Dt#2.sex#1.child_grp="< 5 " 1.Dt#2.sex#2.child_grp="5-17 "  ,wrap(20) interaction(" x ")) 
baselevel legend(r(1)) levels(95) ciopts(recast(rcap))  graphregion(color(white));
#delimit cr



********************************************************************************
* Regressions: Broad Employment *
*********************************


// SPEC 2: aggregates broad employment
preserve

keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Overall change, without controls (except quarter and education dummies)
qui reg broad_emp  Dt                                     i.sum_edu i.Qt  [pw=wtfinl],  robust 
est store bench_nocontrols  
matrix table_bench_nocontrols = r(table) //store reg results


* Overall change, with benchmark controls
qui reg broad_emp Dt                                     i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store bench_controls  
matrix table_bench_controls = r(table) //store reg results


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 7a") modify 
putexcel A1 =  "Statistic:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel D1 =  "Overall Employment (no cont)"
putexcel D2=table_bench_nocontrols[1,1] 
putexcel D3=table_bench_nocontrols[2,1] 
putexcel D4=table_bench_nocontrols[4,1] 

putexcel E1 =  "Overall Employment (with cont)"
putexcel E2=table_bench_controls[1,1] 
putexcel E3=table_bench_controls[2,1] 
putexcel E4=table_bench_controls[4,1] 


restore




// SPEC 2A: Broad Employment, includes summer education dummies, interacted with detailed child groups, only gender specific trends
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
qui reg broad_emp Dt##ib1.sex c.time_var#ib1.sex                                      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results


qui reg broad_emp Dt##ib1.sex  c.time_var#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
qui reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex                       i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results


qui reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results


restore 


#delimit ;
coefplot  (bench,label(Population)) (kid,  label(Kid Interaction))    , bylabel("Benchmark") 
|| (bench_occ,  label(Population)) (kid_occ, label(Kid Interaction)) ,bylabel("Ind and Occ Controls") yscale(range(-0.15(0.05)0))
name(broad_emp_kids,replace) vertical drop(_cons) keep(1.Dt#2.sex*) yline(0) title("") graphregion(color(white)) ytitle("broad employment")
coeflabels(1.Dt#2.sex="Pop" 1.Dt#2.sex#0.child_grp="None" 1.Dt#2.sex#1.child_grp="< 5 " 1.Dt#2.sex#2.child_grp="5-17 "  ,wrap(20) interaction(" x ")) 
baselevel legend(r(1)) levels(95) ciopts(recast(rcap))  graphregion(color(white));
#delimit cr


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 7b") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Population (bench)"
putexcel B2=table_bench[1,8] 
putexcel B3=table_bench[2,8] 
putexcel B4=table_bench[4,8] 

putexcel C1 =  "No Kids (bench)"
putexcel C2=table_kid[1,22]   
putexcel C3=table_kid[2,22] 
putexcel C4=table_kid[4,22] 

putexcel D1 =  "Small Kids (bench)"
putexcel D2=table_kid[1,23] 
putexcel D3=table_kid[2,23] 
putexcel D4=table_kid[4,23] 

putexcel E1 =  "School Kids (bench)"
putexcel E2=table_kid[1,24] 
putexcel E3=table_kid[2,24] 
putexcel E4=table_kid[4,24] 

//...and with occ controls

* Regression Results
putexcel F1 =  "Population (work type)"
putexcel F2=table_bench_occ[1,8] 
putexcel F3=table_bench_occ[2,8] 
putexcel F4=table_bench_occ[4,8] 

putexcel G1 =  "No Kids (work type)"
putexcel G2=table_kid_occ[1,22]   
putexcel G3=table_kid_occ[2,22] 
putexcel G4=table_kid_occ[4,22] 

putexcel H1 =  "Small Kids (work type)"
putexcel H2=table_kid_occ[1,23] 
putexcel H3=table_kid_occ[2,23] 
putexcel H4=table_kid_occ[4,23] 

putexcel I1 =  "School Kids (work type)"
putexcel I2=table_kid_occ[1,24] 
putexcel I3=table_kid_occ[2,24] 
putexcel I4=table_kid_occ[4,24] 




// SPEC 2B: Broad Employment, includes summer education dummies, interacted with detailed child groups, gender x child_grp specific trends
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
qui reg broad_emp Dt##ib1.sex c.time_var#ib1.sex                                                 i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store bench  


qui reg broad_emp Dt##ib1.sex  c.time_var#ib1.sex  Dt##i.work_type                               i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust  
est store bench_occ


* By Child Group
qui reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex#ib0.child_grp                    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store kid

qui reg broad_emp Dt##ib1.sex#ib0.child_grp  c.time_var#ib1.sex#ib0.child_grp   Dt##i.work_type  i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ i.married [pw=wtfinl],  robust 
est store  kid_occ

restore 



#delimit ;
coefplot  (bench,label(Population)) (kid,  label(Kid Interaction))    , bylabel("Benchmark") 
|| (bench_occ,  label(Population)) (kid_occ, label(Kid Interaction)) ,bylabel("Ind and Occ Controls") yscale(range(-0.15(0.05)0))
name(broad_emp_kids_kidtrends,replace) vertical drop(_cons) keep(1.Dt#2.sex*) yline(0) title("") graphregion(color(white)) ytitle("broad employment")
coeflabels(1.Dt#2.sex="Pop" 1.Dt#2.sex#0.child_grp="None" 1.Dt#2.sex#1.child_grp="< 5 " 1.Dt#2.sex#2.child_grp="5-17 "  ,wrap(20) interaction(" x ")) 
baselevel legend(r(1)) levels(95) ciopts(recast(rcap))  graphregion(color(white));
#delimit cr





********************************************************************************
* Regressions: Education Levels *
*********************************

// SPEC 3A: Hours Education Regressions
***************************************
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
 reg hours_lwk Dt##ib1.sex#ib0.college c.time_var#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.college  c.time_var#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Plot
#delimit ;
coefplot  (bench,label(Population)) (kid,  label(Kid Interaction))    , bylabel("Benchmark") 
|| (bench_occ,  label(Population)) (kid_occ, label(Kid Interaction)) ,bylabel("Ind and Occ Controls")  
name(hours_edu_bench,replace)  drop(_cons) keep(1.Dt#2.sex*) yline(0) title("") graphregion(color(white)) ytitle("hours last week")
coeflabels(1.Dt#2.sex="Pop" 1.Dt#2.sex#0.child_grp="None" 1.Dt#2.sex#1.child_grp="< 5 " 1.Dt#2.sex#2.child_grp="5-17 "  ,wrap(20) interaction(" x ")) 
baselevel legend(r(1)) levels(95) ciopts(recast(rcap))  graphregion(color(white));
#delimit cr



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 12") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids Low Skill  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids High Skill  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids Low Skill  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids High Skill  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 



//...and with occ controls

putexcel J1 =  "Pop Low Skill (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop High Skill (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids Low Skill  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids High Skill  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids Low Skill  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids High Skill  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids Low Skill  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids High Skill  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 



// SPEC 3B: Employment Education Regressions
********************************************
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
 reg broad_emp Dt##ib1.sex#ib0.college c.time_var#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.college  c.time_var#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.child_grp#ib0.college  c.time_var#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Plot
#delimit ;
coefplot  (bench,label(Population)) (kid,  label(Kid Interaction))    , bylabel("Benchmark") 
|| (bench_occ,  label(Population)) (kid_occ, label(Kid Interaction)) ,bylabel("Ind and Occ Controls")  
name(brdemp_edu_bench,replace)  drop(_cons) keep(1.Dt#2.sex*) yline(0) title("") graphregion(color(white)) ytitle("employment")
coeflabels(1.Dt#2.sex="Pop" 1.Dt#2.sex#0.child_grp="None" 1.Dt#2.sex#1.child_grp="< 5 " 1.Dt#2.sex#2.child_grp="5-17 "  ,wrap(20) interaction(" x ")) 
baselevel legend(r(1)) levels(95) ciopts(recast(rcap))  graphregion(color(white));
#delimit cr



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 11") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop Low Skill (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop High Skill (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids Low Skill  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids High Skill  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids Low Skill  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids High Skill  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids Low Skill  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids High Skill  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop Low Skill (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop High Skill (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids Low Skill  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids High Skill  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids Low Skill  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids High Skill  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids Low Skill  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids High Skill  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 



********************************************************************************
* Regressions: Single Motherhood *
**********************************

* Compare mothers who are working and not working by child group 

// SPEC 4: Hours Last Week
preserve

* Mothers Sample
keep if sex==2 & (child_grp==1 | child_grp==2) // mothers of children < 18 only
//replace child_grp = 1 if child_grp==2

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications

* Regressions

* Mothers Labor Supply by Marital Status
//...without controls
*reg hours_lwk ib0.married ib0.Dt#ib0.married    i.sum_edu i.Qt          								   [pw=wtfinl],robust

//...with controls
*reg hours_lwk ib0.married ib0.Dt#ib0.married    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ  [pw=wtfinl],robust

* Regression Set
* Hours
reg hours_lwk Dt##ib1.married#ib0.child_grp    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ [pw=wtfinl] , robust 							   
matrix motherhood = r(table) //store reg results

reg hours_lwk Dt##ib1.married#ib0.child_grp Dt#i.work_type  i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ [pw=wtfinl] , robust 							   
matrix motherhood_occ = r(table) //store reg results


* Employment
reg broad_emp Dt##ib1.married#ib0.child_grp    i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ [pw=wtfinl] , robust 							   
matrix motherhood_emp = r(table) //store reg results

reg broad_emp Dt##ib1.married#ib0.child_grp Dt#i.work_type  i.sum_edu i.Qt i.age_grp i.simp_race i.simp_educ [pw=wtfinl] , robust 							   
matrix motherhood_emp_occ = r(table) //store reg results


restore



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 15") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"
* Regression Results
//hours
putexcel B1 =  "Hours Single Mom - Small Kids (bench)"
putexcel B2=motherhood[1,13]
putexcel B3=motherhood[2,13]
putexcel B4=motherhood[4,13]

putexcel C1 =  "Hours Single Mom - School Kids (bench)"
putexcel C2=motherhood[1,14]
putexcel C3=motherhood[2,14]
putexcel C4=motherhood[4,14]

putexcel D1 =  "Hours Single Mom - Small Kids (work type)"
putexcel D2=motherhood_occ[1,13]
putexcel D3=motherhood_occ[2,13]
putexcel D4=motherhood_occ[4,13]

putexcel E1 =  "Hours Single Mom - School Kids (work type)"
putexcel E2=motherhood_occ[1,14]
putexcel E3=motherhood_occ[2,14]
putexcel E4=motherhood_occ[4,14]


//employment
putexcel F1 =  "Employment Single Mom - Small Kids (bench)"
putexcel F2=motherhood_emp[1,13]
putexcel F3=motherhood_emp[2,13]
putexcel F4=motherhood_emp[4,13]

putexcel G1 =  "Employment Single Mom - School Kids (bench)"
putexcel G2=motherhood_emp[1,14]
putexcel G3=motherhood_emp[2,14]
putexcel G4=motherhood_emp[4,14]

putexcel H1 =  "Employment Single Mom - Small Kids (work type)"
putexcel H2=motherhood_emp_occ[1,13]
putexcel H3=motherhood_emp_occ[2,13]
putexcel H4=motherhood_emp_occ[4,13]

putexcel I1 =  "Employment Single Mom - School Kids (work type)"
putexcel I2=motherhood_emp_occ[1,14]
putexcel I3=motherhood_emp_occ[2,14]
putexcel I4=motherhood_emp_occ[4,14]






********************************************************************************
* Regressions: Broad Race (white v non-white) *
***********************************************



// SPEC 4A: Hours gender gap and broad race (white v non-white)
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
  reg hours_lwk Dt##ib1.sex#i.simp_race c.time_var#ib1.sex                                      i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

  reg hours_lwk Dt##ib1.sex#i.simp_race  c.time_var#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var#ib1.sex                       i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results


restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 14") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"


* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids White  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids Non-white  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids White  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids Non-white  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop White (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop Non-white (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids White  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids Non-white  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids White  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids Non-white  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids White  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids Non-white  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 


// SPEC 4B: Employment gender gap and broad race (white v non-white)
preserve

* Time Sample
keep if year>=`samp_yr'

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
  reg broad_emp Dt##ib1.sex#i.simp_race c.time_var#ib1.sex                                      i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

  reg broad_emp Dt##ib1.sex#i.simp_race  c.time_var#ib1.sex  Dt##i.work_type                    i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg broad_emp Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var#ib1.sex                       i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg broad_emp Dt##ib1.sex#ib0.child_grp#i.simp_race  c.time_var#ib1.sex  Dt##i.work_type      i.sum_edu i.Qt i.age_grp  i.simp_educ i.married [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 13") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop White (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Non-white (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids White  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids Non-white  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids White  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids Non-white  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids White  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids Non-white  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 


//...and with occ controls
putexcel J1 =  "Pop White (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop Non-white (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids White  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids Non-white  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids White  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids Non-white  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids White  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids Non-white  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 





********************************************************************************
* Regressions: Telecomutting (white v non-white) *
***********************************************
* NOTE: Data on telecomutting is only available for employed individuals
* from May 2020. As a result, we can only study intensive difference (for employed)
* and have to back fill telecomutting status data to run our regressions. 


* Telecomutting Datasets 
preserve

//sub sample
keep if Dt~=. | year>=2020 // pandemic sample
keep if broad_emp==1 //only ones with TC data

* Telecomutting "Fixed Effect" based on ever telecomutting because of COVID
gen TC_now = .
replace TC_now = 0 if covidtelew==1 //non-tele employed
replace TC_now = 1 if covidtelew==2 //tele employed
egen TC = max(TC_now), by(cpsidp) // assigned telecomutting if ever did during May - Oct

tempfile TC_data
save `TC_data'

restore



// 3(A)  Trend in Telecomutting because of COVID by Gender and Marital Status
preserve

* Sample
use `TC_data',clear

local start_data = ym(2020,5)
drop if time_var<`start_data'

collapse hours_lwk [pw=wtfinl], by(TC sex child_grp)


* Write out results
export excel using `out_reg_table',  sheet("Table 17")  sheetrep first(var)


restore




* SPEC 5(A): TELECOMUTTING CROSS-SECTIONAL REGRESSIONS 
preserve


* Sample
use `TC_data',clear

* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications


* Population
 reg hours_lwk Dt##ib1.sex#ib0.TC c.time_var#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.TC  c.time_var#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.TC  c.time_var#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.TC  c.time_var#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pw=wtfinl],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 


* Plot
#delimit ;
coefplot  (bench,label(Population)) (kid,  label(Kid Interaction))    , bylabel("Benchmark") 
|| (bench_occ,  label(Population)) (kid_occ, label(Kid Interaction)) ,bylabel("Ind and Occ Controls")  
name(hours_TC,replace)  drop(_cons) keep(1.Dt#2.sex*) yline(0) title("") graphregion(color(white)) ytitle("hours last week")
coeflabels(1.Dt#2.sex="Pop" 1.Dt#2.sex#0.child_grp="None" 1.Dt#2.sex#1.child_grp="< 5 " 1.Dt#2.sex#2.child_grp="5-17 "  ,wrap(20) interaction(" x ")) 
baselevel legend(r(1)) levels(95) ciopts(recast(rcap))  graphregion(color(white)) xline(0);
#delimit cr



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set `out_reg_table' , sheet("Table 16") modify 
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop NTC (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop Tele (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids NTC  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids Tele  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids NTC  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids Tele  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids NTC  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids Tele  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 



//...and with occ controls

putexcel J1 =  "Pop NTC (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop Tele (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids NTC  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids Tele  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids NTC  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids Tele  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids NTC  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids Tele  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 



********************************************************************************
********************************************************************************

********************
* APPENDIX TABLES *
******************** 

* Auxiliary Stats on Workforce Composition for Appendix Tables

* Table A1: subgroup shares in workforce
preserve

keep if year == 2019 // year for sample

gen living_with_kids = .
replace living_with_kids = 0 if yngch>=15 | nchild==0
replace living_with_kids = 1 if yngch<15

gen mother = 0
replace mother = 1 if sex==2 & living_with_kids==1


gen single_mother = 0
replace single_mother = 1 if sex==2 & living_with_kids==1 & marst~=1


collapse living_with_kids mother single_mother [aw=wtfinl]
sum


* Write out results
export excel using `out_reg_table',  sheet("Table A1")  sheetrep first(var)


restore


* Table A2: hours (extensive and intensive
//Grp 1: mothers by kid grp and marital status

preserve

keep if year == 2019 // year for sample

gen hrs_sing_04  = raw_hours_lwk if (sex==2 & yngch<=4 & married==0) //single mothers,  kids 0-4
gen hrs_marr_04  = raw_hours_lwk if (sex==2 & yngch<=4 & married==1) //married mothers,  kids 0-4
gen hrs_sing_514 = raw_hours_lwk if (sex==2 & yngch>=5 & yngch<15 & married==0) //single mothers,  kids 0-4
gen hrs_marr_514 = raw_hours_lwk if (sex==2 & yngch>=5 & yngch<15 & married==1) //married mothers,  kids 0-4

gen hrs_non_mom = raw_hours_lwk if (sex==2 & yngch>=15) | (sex==2 & nchild==0) // non-mothers
gen hrs_dad_014 = raw_hours_lwk if (sex==1 & yngch<15) // fathers of kids 0-14
gen hrs_non_dad = raw_hours_lwk if (sex==1 & yngch>=15) | (sex==1 & nchild==0) // non-fathers

collapse hrs_* [pw=wtfinl]

* Write out results
export excel using `out_reg_table',  sheet("Table A2")  sheetrep first(var)



restore




********************************************************************************
********************************************************************************
log close






